Simple demo of dojox.help.console

You'll want to open up Firebug for this

Click each of the items below to run the command:

- `dojo.require("dojox.help.console");`
- `dojox.help.locate("Xhr", dojo);` searches variable names in the dojo namespaces for "Xhr" (no matter the case).
- `dojo.query.help();` displays help for dojo.byId
- `dojo.connect` loads and displays the function signature for dojo.connect
- `dojo.isBrowser` shows an example of a "conflict". It's using the Boolean object rather than the boolean generic.
- `dojox.help.noConflict();` fixes this conflict (click on `dojo.isBrowser` again).
- `dojox.help.refresh();` parses the page again!
- `dojo.isBrowser` and the conflict is back again!